@@ -1,9 +1,9 @@
 package App::PDFUtils;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-13'; # DATE
+our $DATE = '2021-07-17'; # DATE
 our $DIST = 'App-PDFUtils'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -272,6 +272,10 @@ _
         %argspecopt1_output,
         %argspecopt_overwrite,
         %argspecopt_return_output_file,
+        pages => {
+            summary => 'Only convert a range of pages',
+            schema => 'uint_range*',
+        },
         fmt => {
             summary => 'Run Unix fmt over the txt output',
             schema => 'bool*',
@@ -306,9 +310,24 @@ sub convert_pdf_to_text {
         my $tempdir = File::Temp::tempdir(CLEANUP => !$args{return_output_file});
         my ($temp_fh, $temp_file)      = File::Temp::MoreUtils::tempfile_named(name=>$input_file, dir=>$tempdir);
         (my $temp_out_file = $temp_file) =~ s/\.\w+\z/.txt/;
-        File::Copy::copy($input_file, $temp_file) or do {
-            return [500, "Can't copy '$input_file' to '$temp_file': $!"];
-        };
+
+        if (defined $args{pages}) {
+            File::Which::which("pdftk")
+                  or return [412, "pdftk is required to extract page range from PDF"];
+            IPC::System::Options::system(
+                {die=>1, log=>1},
+                "pdftk", $input_file, "cat", $args{pages}, "output", $temp_file);
+        } else {
+            File::Copy::copy($input_file, $temp_file) or do {
+                return [500, "Can't copy '$input_file' to '$temp_file': $!"];
+            };
+        }
+
+      EXTRACT_PAGE_RANGE: {
+            last unless defined $args{pages};
+
+        }
+
         IPC::System::Options::system(
             {die=>1, log=>1},
             "pdftotext", $temp_file, $temp_out_file);
@@ -363,7 +382,7 @@ App::PDFUtils - Command-line utilities related to PDF files
 
 =head1 VERSION
 
-This document describes version 0.006 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2021-07-13.
+This document describes version 0.007 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2021-07-17.
 
 =head1 SYNOPSIS
 
@@ -462,6 +481,10 @@ Output path.
 
 =item * B<overwrite> => I<bool>
 
+=item * B<pages> => I<uint_range>
+
+Only convert a range of pages.
+
 =item * B<return_output_file> => I<bool>
 
 Return the path of output file instead.
